import './connection.css'
import {
    useId,
    Button,
    FieldProps,
    Spinner
} from "@fluentui/react-components";
import {Field, Input} from "@fluentui/react-components";
import {useNavigate} from "react-router-dom";
import {useState} from "react";
import {Dial} from "../../api";
import {useToast} from "../../message";
import {CheckmarkFilled, DismissRegular} from "@fluentui/react-icons";


const Connection = (props: Partial<FieldProps>) => {
    const { dispatchMessage } = useToast();
    const navigate = useNavigate();
    const [testLoading, setTestLoading] = useState<"initial" | "loading" | "success" | "error">("initial");
    const buttonIcon =
        testLoading === "loading" ? (
            <Spinner size="tiny"/>
        ) : testLoading === "success" ? (
            <CheckmarkFilled/>
        ) : testLoading === "error" ? (
            <DismissRegular/>
        ) : null;
    const [value, setValue] = useState<{ name: string, endpoint: string, access: string, key: string }>({
        name: '',
        endpoint: '',
        access: '',
        key: ''
    })

    function test() {
        setTestLoading("loading")
        Dial<string>("/api/connection/test", value).then(res => {
            let status: "success" | "error" = "error"
            if (res.status === 200) {
                status = "success"
            }

            setTestLoading(status);

            dispatchMessage(res.msg, status)
        })
    }

    function create() {
        Dial<unknown>("/api/connection/create", value).then(res => {
            dispatchMessage(res.msg, res.status === 200?"success":"error");
            if (res.status === 200) {
                navigate("/");
            }
        })
    }

    return <div className='connection-container'>
        <div className='connection-form'>
            <div className='connection-form-field'>
                <Field
                    label="name"
                    validationState="success"
                    validationMessage="This is a success message."
                    {...props}
                >
                    <Input placeholder='名称 (example: 测试S3-minio)' value={value.name} onChange={(e) => {
                        setValue({...value, name: e.target.value});
                    }}/>
                </Field>
            </div>
            <div className='connection-form-field'>
                <Field
                    label="endpoint"
                    validationState="success"
                    validationMessage="This is a success message."
                    {...props}
                >
                    <Input placeholder='地址 (example: https://ip_or_server-name:port)' value={value.endpoint}
                           onChange={(e) => {
                               setValue({...value, endpoint: e.target.value});
                           }}/>
                </Field>
            </div>
            <div className='connection-form-field'>
                <Field
                    label="secret access"
                    validationState="success"
                    validationMessage="This is a success message."
                    {...props}
                >
                    <Input placeholder='' value={value.access} onChange={(e) => {
                        setValue({...value, access: e.target.value});
                    }}/>
                </Field>
            </div>
            <div className='connection-form-field'>
                <Field
                    label="secret key"
                    validationState="success"
                    validationMessage="This is a success message."
                    {...props}
                >
                    <Input placeholder='' value={value.key} onChange={(e) => {
                        setValue({...value, key: e.target.value});
                    }}/>
                </Field>
            </div>
            <div className='connection-form-field connection-form-field-actions'>
                <Button appearance='transparent' icon={buttonIcon} onClick={() => test()}>测试连接</Button>
                <div style={{marginLeft: 'auto'}}>
                    <Button style={{marginRight: '20px'}} className='connection-form-field-actions-cancel'
                            onClick={() => {
                                navigate("/")
                            }}>取消</Button>
                    <Button className='connection-form-field-actions-confirm' appearance='primary'
                            onClick={() => create()}>新建</Button>
                </div>
            </div>
        </div>
    </div>
}

export default Connection;