import {useEffect, useState} from 'react';
import './home.css';
import {
    Button,
} from "@fluentui/react-components";
import {
    CloudAddFilled, DismissRegular
} from "@fluentui/react-icons";
import {useNavigate} from "react-router-dom";
import {Dial} from "../../api";
import {useToast} from "../../message";
import {Connection} from "../../interfaces/connection";

function Home() {
    const {dispatchMessage} = useToast();
    const [connectionFilterKeywords, setConnectionFilterKeywords] = useState<string>('');
    const navigate = useNavigate();
    const [connectionList, setConnectionList] = useState<Connection[]>([]);

    useEffect(() => {
        Dial<{ list: Connection[] }>("/api/connection/list").then(res => {
            dispatchMessage(res.msg, res.status === 200 ? "success" : "error");
            if (res.status === 200) {
                setConnectionList(res.data.list)
            }
        })
    }, []);

    return (
        <div className="container">
            <div className="header">
                <Button appearance="primary" icon={<CloudAddFilled/>} onClick={() => {
                    navigate("/connection")
                }}>
                    新建连接
                </Button>
            </div>
            <div className="body">
                <div className="body-connections">
                    <div className="body-connections-search">
                        <input className="body-connections-search-input" type={"text"} placeholder="搜索连接"
                               value={connectionFilterKeywords}
                               onChange={(e) => setConnectionFilterKeywords(e.target.value)}/>
                        <div className="body-connections-search-dismiss" onClick={() => {
                            setConnectionFilterKeywords('')
                        }}>
                            <DismissRegular/>
                        </div>
                    </div>
                    <div className="body-connections-list"></div>
                </div>
                <div className="body-content"></div>
            </div>
            <div className="footer"></div>
        </div>
    )
}

export default Home
